Module piece_content

Module piece_content 

Structs

PieceContent
PieceContent represents a piece metadata and piece content request.
PieceMetadata
PieceMetadata holds the metadata information for a piece.

Constants

METADATA_LENGTH_SIZE
METADATA_LENGTH_SIZE is the size of the metadata length in bytes.